@@ -1,4 +1,6 @@
 pub mod gen;
 pub mod pattern;
 pub mod spec;
+#[cfg(test)]
+mod tests;
 pub mod whitespace;
